@@ -35,8 +35,8 @@ KReportItemField::KReportItemField()
 }
 
 KReportItemField::KReportItemField(const QDomNode & element)
+    : KReportItemField()
 {
-    createProperties();
     QDomNodeList nl = element.childNodes();
     QString n;
     QDomNode node;
@@ -71,10 +71,10 @@ KReportItemField::KReportItemField(const QDomNode & element)
             if (parseReportLineStyleData(node.toElement(), &ls)) {
                 m_lineWeight->setValue(ls.width());
                 m_lineColor->setValue(ls.color());
-                m_lineStyle->setValue(QPen(ls.penStyle()));
+                m_lineStyle->setValue(static_cast<int>(ls.penStyle()));
             }
         } else {
-            kreportpluginWarning() << "while parsing field element encountered unknow element: " << n;
+            kreportpluginWarning() << "while parsing field element encountered unknown element: " << n;
         }
     }
 }
@@ -115,9 +115,10 @@ void KReportItemField::createProperties()
     m_backgroundOpacity->setOption("min", 0);
     m_backgroundOpacity->setOption("unit", QLatin1String("%"));
 
-    m_lineWeight = new KProperty("line-weight", 1, tr("Line Weight"));
+    m_lineWeight = new KProperty("line-weight", 1.0, tr("Line Weight"));
+    m_lineWeight->setOption("step", 1.0);
     m_lineColor = new KProperty("line-color", QColor(Qt::black), tr("Line Color"));
-    m_lineStyle = new KProperty("line-style", QPen(Qt::NoPen), tr("Line Style"), tr("Line Style"), KProperty::LineStyle);
+    m_lineStyle = new KProperty("line-style", static_cast<int>(Qt::NoPen), tr("Line Style"), tr("Line Style"), KProperty::LineStyle);
 
     m_wordWrap = new KProperty("word-wrap", QVariant(false), tr("Word Wrap"));
     m_canGrow = new KProperty("can-grow", QVariant(false), tr("Can Grow"));
@@ -204,7 +205,7 @@ void KReportItemField::setItemDataSource(const QString& t)
 KReportLineStyle KReportItemField::lineStyle() const
 {
     KReportLineStyle ls;
-    ls.setWidth(m_lineWeight->value().toInt());
+    ls.setWidth(m_lineWeight->value().toReal());
     ls.setColor(m_lineColor->value().value<QColor>());
     ls.setPenStyle((Qt::PenStyle)m_lineStyle->value().toInt());
     return ls;
