@@ -42,16 +42,14 @@
 typedef QVector<double> datalist;
 
 KReportItemChart::KReportItemChart()
+    : m_reportData(nullptr)
 {
-    m_reportData = 0;
     createProperties();
 }
 
 KReportItemChart::KReportItemChart(QDomNode *element)
+    : KReportItemChart()
 {
-    m_reportData = 0;
-    createProperties();
-
     QDomNodeList nl = element->childNodes();
 
     QString n;
@@ -423,8 +421,12 @@ int KReportItemChart::renderReportData(OROPage *page, OROSection *section, const
         if (page) page->addPrimitive(pic);
 
         OROPicture *p2 = static_cast<OROPicture*>(pic->clone());
-        p2->setPosition(m_pos.toPoint());
-        if (section) section->addPrimitive(p2);
+        if (p2) {
+            p2->setPosition(m_pos.toPoint());
+            if (section) {
+                section->addPrimitive(p2);
+            }
+        }
     }
 
     return 0;
