@@ -66,7 +66,7 @@ KReportDesignerItemWeb *KReportDesignerItemWeb::clone() //done,compared
     QDomNode n;
     buildXML(&d, &e);
     n = e.firstChild();
-    return new KReportDesignerItemWeb(n, designer(), 0);
+    return new KReportDesignerItemWeb(n, designer(), nullptr);
 }
 
 KReportDesignerItemWeb::~KReportDesignerItemWeb() //done,compared
