@@ -107,26 +107,26 @@ class KReportDesigner::Private
 {
 public:
     Private()
-        : activeScene(0)
-        , reportHeader(0)
-        , pageHeaderFirst(0)
-        , pageHeaderOdd(0)
-        , pageHeaderEven(0)
-        , pageHeaderLast(0)
-        , pageHeaderAny(0)
-        , pageFooterFirst(0)
-        , pageFooterOdd(0)
-        , pageFooterEven(0)
-        , pageFooterLast(0)
-        , pageFooterAny(0)
-        , reportFooter(0)
-        , detail(0)
+        : activeScene(nullptr)
+        , reportHeader(nullptr)
+        , pageHeaderFirst(nullptr)
+        , pageHeaderOdd(nullptr)
+        , pageHeaderEven(nullptr)
+        , pageHeaderLast(nullptr)
+        , pageHeaderAny(nullptr)
+        , pageFooterFirst(nullptr)
+        , pageFooterOdd(nullptr)
+        , pageFooterEven(nullptr)
+        , pageFooterLast(nullptr)
+        , pageFooterAny(nullptr)
+        , reportFooter(nullptr)
+        , detail(nullptr)
         , pressX(-1)
         , pressY(-1)
         , releaseX(-1)
         , releaseY(-1)
         , modified(false)
-        , kordata(0)
+        , kordata(nullptr)
     {}
 
     ~Private()
@@ -292,7 +292,10 @@ KReportDesigner::KReportDesigner(QWidget *parent, const QDomElement &data)
                 setReportTitle(it.firstChild().nodeValue());
 #ifdef KREPORT_SCRIPTING
             } else if (n == QLatin1String("report:script")) {
-                d->originalInterpreter = it.toElement().attribute(QLatin1String("report:script-interpreter"));
+                d->originalInterpreter = it.toElement().attribute(QLatin1String("report:script-interpreter"), QLatin1String("javascript"));
+                if (d->originalInterpreter.isEmpty()) {
+                    d->originalInterpreter = QLatin1String("javascript");
+                }
                 d->originalScript = it.firstChild().nodeValue();
                 d->script->setValue(d->originalScript);
 
@@ -344,7 +347,7 @@ KReportDesigner::KReportDesigner(QWidget *parent, const QDomElement &data)
                         //kreportDebug() << sn;
                         if (sn == QLatin1String("report:section")) {
                             QString sectiontype = sec.toElement().attribute(QLatin1String("report:section-type"));
-                            if (section(KReportSectionData::sectionTypeFromString(sectiontype)) == 0) {
+                            if (section(KReportSectionData::sectionTypeFromString(sectiontype)) == nullptr) {
                                 insertSection(KReportSectionData::sectionTypeFromString(sectiontype));
                                 section(KReportSectionData::sectionTypeFromString(sectiontype))->initFromXML(sec);
                             }
@@ -385,18 +388,21 @@ QDomElement KReportDesigner::document() const
     content.appendChild(propertyToElement(&doc, d->title));
 
 #ifdef KREPORT_SCRIPTING
+    if (d->originalInterpreter.isEmpty()) {
+        d->originalInterpreter = QLatin1String("javascript");
+    }
+    saveInterpreter = d->originalInterpreter;
+
     if (!d->script->value().toString().isEmpty()) {
-        if (d->script->value().toString() != d->originalScript || d->originalInterpreter == QLatin1String("qtscript")) {
+        if (d->script->value().toString() != d->originalScript || d->originalInterpreter == QLatin1String("qtscript") || d->originalInterpreter.isEmpty() ) {
             //The script has changed so force interpreter to 'javascript'.  Also set if was using qtscript
             saveInterpreter = QLatin1String("javascript");
-        } else {
-            saveInterpreter = d->originalInterpreter;
         }
-
-        QDomElement scr = propertyToElement(&doc, d->script);
-        scr.setAttribute(QLatin1String("report:script-interpreter"), saveInterpreter);
-        content.appendChild(scr);
     }
+
+    QDomElement scr = propertyToElement(&doc, d->script);
+    scr.setAttribute(QLatin1String("report:script-interpreter"), saveInterpreter);
+    content.appendChild(scr);
 #endif
 
     QDomElement grd = doc.createElement(QLatin1String("report:grid"));
@@ -516,7 +522,7 @@ KReportDesignerSection * KReportDesigner::section(KReportSectionData::Section s)
         sec = d->reportFooter;
         break;
     default:
-        sec = 0;
+        sec = nullptr;
     }
     return sec;
 }
@@ -528,43 +534,43 @@ void KReportDesigner::removeSection(KReportSectionData::Section s)
 
         switch (s) {
         case KReportSectionData::PageHeaderAny:
-            d->pageHeaderAny = 0;
+            d->pageHeaderAny = nullptr;
             break;
         case KReportSectionData::PageHeaderEven:
-            sec = d->pageHeaderEven = 0;
+            sec = d->pageHeaderEven = nullptr;
             break;
         case KReportSectionData::PageHeaderOdd:
-            d->pageHeaderOdd = 0;
+            d->pageHeaderOdd = nullptr;
             break;
         case KReportSectionData::PageHeaderFirst:
-            d->pageHeaderFirst = 0;
+            d->pageHeaderFirst = nullptr;
             break;
         case KReportSectionData::PageHeaderLast:
-            d->pageHeaderLast = 0;
+            d->pageHeaderLast = nullptr;
             break;
         case KReportSectionData::PageFooterAny:
-            d->pageFooterAny = 0;
+            d->pageFooterAny = nullptr;
             break;
         case KReportSectionData::PageFooterEven:
-            d->pageFooterEven = 0;
+            d->pageFooterEven = nullptr;
             break;
         case KReportSectionData::PageFooterOdd:
-            d->pageFooterOdd = 0;
+            d->pageFooterOdd = nullptr;
             break;
         case KReportSectionData::PageFooterFirst:
-            d->pageFooterFirst = 0;
+            d->pageFooterFirst = nullptr;
             break;
         case KReportSectionData::PageFooterLast:
-            d->pageFooterLast = 0;
+            d->pageFooterLast = nullptr;
             break;
         case KReportSectionData::ReportHeader:
-            d->reportHeader = 0;
+            d->reportHeader = nullptr;
             break;
         case KReportSectionData::ReportFooter:
-            d->reportFooter = 0;
+            d->reportFooter = nullptr;
             break;
         default:
-            sec = 0;
+            sec = nullptr;
         }
 
         setModified(true);
@@ -900,7 +906,7 @@ void KReportDesigner::setDetail(KReportDesignerSectionDetail *rsd)
 void KReportDesigner::deleteDetail()
 {
     delete d->detail;
-    d->detail = 0;
+    d->detail = nullptr;
 }
 
 KReportUnit KReportDesigner::pageUnit() const
@@ -993,7 +999,7 @@ void KReportDesigner::sectionMouseReleaseEvent(KReportDesignerSectionView * v, Q
         }
 
         if (d->sectionData->mouseAction == ReportWriterSectionData::MA_Insert) {
-            QGraphicsItem * item = 0;
+            QGraphicsItem * item = nullptr;
             QString classString;
             QString iconName;
             if (d->sectionData->insertItem == QLatin1String("org.kde.kreport.line")) {
@@ -1072,7 +1078,7 @@ void KReportDesigner::slotItem(const QString &entity)
 
 void KReportDesigner::slotEditDelete()
 {
-    QGraphicsItem * item = 0;
+    QGraphicsItem * item = nullptr;
     bool modified = false;
     while (selectionCount() > 0) {
         item = activeScene()->selectedItems().value(0);
@@ -1155,7 +1161,7 @@ void KReportDesigner::slotEditPaste(QGraphicsScene * canvas)
     // paste a new item of the copy we have in the specified location
     if (!d->sectionData->copy_list.isEmpty()) {
         QList<QGraphicsItem*> activeItems = canvas->selectedItems();
-        QGraphicsItem *activeItem = 0;
+        QGraphicsItem *activeItem = nullptr;
         if (activeItems.count() == 1) {
             activeItem = activeItems.first();
         }
@@ -1260,7 +1266,7 @@ QString KReportDesigner::suggestEntityName(const QString &n) const
     return n + QString::number(itemCount);
 }
 
-bool KReportDesigner::isEntityNameUnique(const QString &n, KReportItemBase* ignore) const
+bool KReportDesigner::isEntityNameUnique(const QString &n, KReportItemBase *ignore) const
 {
     KReportDesignerSection *sec;
     bool unique = true;
